pub struct MemtableStats {
pub estimated_bytes: usize,
pub time_range: Option<(Timestamp, Timestamp)>,
pub num_rows: usize,
pub num_ranges: usize,
pub max_sequence: SequenceNumber,
pub min_sequence: SequenceNumber,
pub series_count: usize,
}Fields
estimated_bytes: usizeThe estimated bytes allocated by this memtable from heap.
time_range: Option<(Timestamp, Timestamp)>The inclusive time range that this memtable contains. It is None if and only if the memtable is empty.
num_rows: usizeTotal rows in memtable
num_ranges: usizeTotal number of ranges in the memtable.
max_sequence: SequenceNumberThe maximum sequence number in the memtable.
min_sequence: SequenceNumberLower bound of the row sequences written to this memtable or range. May remain below the actual minimum after deduplication. Zero is conservative when a range does not track its minimum; the value is unused for empty memtables.
series_count: usizeNumber of estimated timeseries in memtable.
Implementations
Sourceimpl MemtableStats
impl MemtableStats
Sourcepub fn bytes_allocated(&self) -> usize
pub fn bytes_allocated(&self) -> usize
Returns the estimated bytes allocated by this memtable.
Sourcepub fn time_range(&self) -> Option<(Timestamp, Timestamp)>
pub fn time_range(&self) -> Option<(Timestamp, Timestamp)>
Returns the time range of the memtable.
Sourcepub fn num_ranges(&self) -> usize
pub fn num_ranges(&self) -> usize
Returns the number of ranges in the memtable.
Sourcepub fn max_sequence(&self) -> SequenceNumber
pub fn max_sequence(&self) -> SequenceNumber
Returns the maximum sequence number in the memtable.
Sourcepub fn series_count(&self) -> usize
pub fn series_count(&self) -> usize
Series count in memtable.